# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPrivateEndpointsResult',
    'AwaitableGetPrivateEndpointsResult',
    'get_private_endpoints',
    'get_private_endpoints_output',
]

@pulumi.output_type
class GetPrivateEndpointsResult:
    """
    A collection of values returned by getPrivateEndpoints.
    """
    def __init__(__self__, compartment_id=None, display_name=None, display_name_starts_with=None, filters=None, id=None, owner_principal_id=None, private_endpoint_collections=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if display_name_starts_with and not isinstance(display_name_starts_with, str):
            raise TypeError("Expected argument 'display_name_starts_with' to be a str")
        pulumi.set(__self__, "display_name_starts_with", display_name_starts_with)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if owner_principal_id and not isinstance(owner_principal_id, str):
            raise TypeError("Expected argument 'owner_principal_id' to be a str")
        pulumi.set(__self__, "owner_principal_id", owner_principal_id)
        if private_endpoint_collections and not isinstance(private_endpoint_collections, list):
            raise TypeError("Expected argument 'private_endpoint_collections' to be a list")
        pulumi.set(__self__, "private_endpoint_collections", private_endpoint_collections)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of a compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name. It does not have to be unique. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="displayNameStartsWith")
    def display_name_starts_with(self) -> Optional[str]:
        return pulumi.get(self, "display_name_starts_with")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetPrivateEndpointsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ownerPrincipalId")
    def owner_principal_id(self) -> Optional[str]:
        """
        The OCID of the user who created the resource.
        """
        return pulumi.get(self, "owner_principal_id")

    @property
    @pulumi.getter(name="privateEndpointCollections")
    def private_endpoint_collections(self) -> Sequence['outputs.GetPrivateEndpointsPrivateEndpointCollectionResult']:
        """
        The list of private_endpoint_collection.
        """
        return pulumi.get(self, "private_endpoint_collections")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of this private endpoint.
        """
        return pulumi.get(self, "state")


class AwaitableGetPrivateEndpointsResult(GetPrivateEndpointsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateEndpointsResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            display_name_starts_with=self.display_name_starts_with,
            filters=self.filters,
            id=self.id,
            owner_principal_id=self.owner_principal_id,
            private_endpoint_collections=self.private_endpoint_collections,
            state=self.state)


def get_private_endpoints(compartment_id: Optional[str] = None,
                          display_name: Optional[str] = None,
                          display_name_starts_with: Optional[str] = None,
                          filters: Optional[Sequence[pulumi.InputType['GetPrivateEndpointsFilterArgs']]] = None,
                          owner_principal_id: Optional[str] = None,
                          state: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateEndpointsResult:
    """
    This data source provides the list of Private Endpoints in Oracle Cloud Infrastructure Data Flow service.

    Lists all private endpoints in the specified compartment. The query must include compartmentId. The query may also include one other parameter. If the query does not include compartmentId, or includes compartmentId, but with two or more other parameters, an error is returned.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_private_endpoints = oci.DataFlow.get_private_endpoints(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name_starts_with=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        owner_principal_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param str display_name: The query parameter for the Spark application name. Note: At a time only one optional filter can be used with `compartment_id` to get the list of Private Endpoint resources.
    :param str display_name_starts_with: The displayName prefix.
    :param str owner_principal_id: The OCID of the user who created the resource.
    :param str state: The LifecycleState of the private endpoint.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['displayNameStartsWith'] = display_name_starts_with
    __args__['filters'] = filters
    __args__['ownerPrincipalId'] = owner_principal_id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataFlow/getPrivateEndpoints:getPrivateEndpoints', __args__, opts=opts, typ=GetPrivateEndpointsResult).value

    return AwaitableGetPrivateEndpointsResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        display_name_starts_with=__ret__.display_name_starts_with,
        filters=__ret__.filters,
        id=__ret__.id,
        owner_principal_id=__ret__.owner_principal_id,
        private_endpoint_collections=__ret__.private_endpoint_collections,
        state=__ret__.state)


@_utilities.lift_output_func(get_private_endpoints)
def get_private_endpoints_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                 display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 display_name_starts_with: Optional[pulumi.Input[Optional[str]]] = None,
                                 filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetPrivateEndpointsFilterArgs']]]]] = None,
                                 owner_principal_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 state: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPrivateEndpointsResult]:
    """
    This data source provides the list of Private Endpoints in Oracle Cloud Infrastructure Data Flow service.

    Lists all private endpoints in the specified compartment. The query must include compartmentId. The query may also include one other parameter. If the query does not include compartmentId, or includes compartmentId, but with two or more other parameters, an error is returned.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_private_endpoints = oci.DataFlow.get_private_endpoints(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name_starts_with=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        owner_principal_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param str display_name: The query parameter for the Spark application name. Note: At a time only one optional filter can be used with `compartment_id` to get the list of Private Endpoint resources.
    :param str display_name_starts_with: The displayName prefix.
    :param str owner_principal_id: The OCID of the user who created the resource.
    :param str state: The LifecycleState of the private endpoint.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMysqlDbSystemsResult',
    'AwaitableGetMysqlDbSystemsResult',
    'get_mysql_db_systems',
    'get_mysql_db_systems_output',
]

@pulumi.output_type
class GetMysqlDbSystemsResult:
    """
    A collection of values returned by getMysqlDbSystems.
    """
    def __init__(__self__, compartment_id=None, configuration_id=None, db_system_id=None, db_systems=None, display_name=None, filters=None, id=None, is_analytics_cluster_attached=None, is_heat_wave_cluster_attached=None, is_up_to_date=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if configuration_id and not isinstance(configuration_id, str):
            raise TypeError("Expected argument 'configuration_id' to be a str")
        pulumi.set(__self__, "configuration_id", configuration_id)
        if db_system_id and not isinstance(db_system_id, str):
            raise TypeError("Expected argument 'db_system_id' to be a str")
        pulumi.set(__self__, "db_system_id", db_system_id)
        if db_systems and not isinstance(db_systems, list):
            raise TypeError("Expected argument 'db_systems' to be a list")
        pulumi.set(__self__, "db_systems", db_systems)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_analytics_cluster_attached and not isinstance(is_analytics_cluster_attached, bool):
            raise TypeError("Expected argument 'is_analytics_cluster_attached' to be a bool")
        pulumi.set(__self__, "is_analytics_cluster_attached", is_analytics_cluster_attached)
        if is_heat_wave_cluster_attached and not isinstance(is_heat_wave_cluster_attached, bool):
            raise TypeError("Expected argument 'is_heat_wave_cluster_attached' to be a bool")
        pulumi.set(__self__, "is_heat_wave_cluster_attached", is_heat_wave_cluster_attached)
        if is_up_to_date and not isinstance(is_up_to_date, bool):
            raise TypeError("Expected argument 'is_up_to_date' to be a bool")
        pulumi.set(__self__, "is_up_to_date", is_up_to_date)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment the DB System belongs in.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="configurationId")
    def configuration_id(self) -> Optional[str]:
        """
        The OCID of the Configuration to be used for Instances in this DB System.
        """
        return pulumi.get(self, "configuration_id")

    @property
    @pulumi.getter(name="dbSystemId")
    def db_system_id(self) -> Optional[str]:
        """
        The OCID of the DB System from which a backup shall be selected to be restored when creating the new DB System. Use this together with recovery point to perform a point in time recovery operation.
        """
        return pulumi.get(self, "db_system_id")

    @property
    @pulumi.getter(name="dbSystems")
    def db_systems(self) -> Sequence['outputs.GetMysqlDbSystemsDbSystemResult']:
        """
        The list of db_systems.
        """
        return pulumi.get(self, "db_systems")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The user-friendly name for the DB System. It does not have to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetMysqlDbSystemsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isAnalyticsClusterAttached")
    def is_analytics_cluster_attached(self) -> Optional[bool]:
        """
        DEPRECATED -- please use `isHeatWaveClusterAttached` instead. If the DB System has an Analytics Cluster attached.
        """
        return pulumi.get(self, "is_analytics_cluster_attached")

    @property
    @pulumi.getter(name="isHeatWaveClusterAttached")
    def is_heat_wave_cluster_attached(self) -> Optional[bool]:
        """
        If the DB System has a HeatWave Cluster attached.
        """
        return pulumi.get(self, "is_heat_wave_cluster_attached")

    @property
    @pulumi.getter(name="isUpToDate")
    def is_up_to_date(self) -> Optional[bool]:
        return pulumi.get(self, "is_up_to_date")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the DB System.
        """
        return pulumi.get(self, "state")


class AwaitableGetMysqlDbSystemsResult(GetMysqlDbSystemsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMysqlDbSystemsResult(
            compartment_id=self.compartment_id,
            configuration_id=self.configuration_id,
            db_system_id=self.db_system_id,
            db_systems=self.db_systems,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            is_analytics_cluster_attached=self.is_analytics_cluster_attached,
            is_heat_wave_cluster_attached=self.is_heat_wave_cluster_attached,
            is_up_to_date=self.is_up_to_date,
            state=self.state)


def get_mysql_db_systems(compartment_id: Optional[str] = None,
                         configuration_id: Optional[str] = None,
                         db_system_id: Optional[str] = None,
                         display_name: Optional[str] = None,
                         filters: Optional[Sequence[pulumi.InputType['GetMysqlDbSystemsFilterArgs']]] = None,
                         is_analytics_cluster_attached: Optional[bool] = None,
                         is_heat_wave_cluster_attached: Optional[bool] = None,
                         is_up_to_date: Optional[bool] = None,
                         state: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMysqlDbSystemsResult:
    """
    This data source provides the list of Mysql Db Systems in Oracle Cloud Infrastructure MySQL Database service.

    Get a list of DB Systems in the specified compartment.
    The default sort order is by timeUpdated, descending.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_mysql_db_systems = oci.Mysql.get_mysql_db_systems(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_analytics_cluster_attached=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_heat_wave_cluster_attached=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_up_to_date=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str configuration_id: The requested Configuration instance.
    :param str db_system_id: The DB System [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only the resource matching the given display name exactly.
    :param bool is_analytics_cluster_attached: DEPRECATED -- please use HeatWave API instead. If true, return only DB Systems with an Analytics Cluster attached, if false return only DB Systems with no Analytics Cluster attached. If not present, return all DB Systems.
    :param bool is_heat_wave_cluster_attached: If true, return only DB Systems with a HeatWave cluster attached, if false return only DB Systems with no HeatWave cluster attached. If not present, return all DB Systems.
    :param bool is_up_to_date: Filter instances if they are using the latest revision of the Configuration they are associated with.
    :param str state: DbSystem Lifecycle State
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['configurationId'] = configuration_id
    __args__['dbSystemId'] = db_system_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['isAnalyticsClusterAttached'] = is_analytics_cluster_attached
    __args__['isHeatWaveClusterAttached'] = is_heat_wave_cluster_attached
    __args__['isUpToDate'] = is_up_to_date
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Mysql/getMysqlDbSystems:getMysqlDbSystems', __args__, opts=opts, typ=GetMysqlDbSystemsResult).value

    return AwaitableGetMysqlDbSystemsResult(
        compartment_id=__ret__.compartment_id,
        configuration_id=__ret__.configuration_id,
        db_system_id=__ret__.db_system_id,
        db_systems=__ret__.db_systems,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        is_analytics_cluster_attached=__ret__.is_analytics_cluster_attached,
        is_heat_wave_cluster_attached=__ret__.is_heat_wave_cluster_attached,
        is_up_to_date=__ret__.is_up_to_date,
        state=__ret__.state)


@_utilities.lift_output_func(get_mysql_db_systems)
def get_mysql_db_systems_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                configuration_id: Optional[pulumi.Input[Optional[str]]] = None,
                                db_system_id: Optional[pulumi.Input[Optional[str]]] = None,
                                display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetMysqlDbSystemsFilterArgs']]]]] = None,
                                is_analytics_cluster_attached: Optional[pulumi.Input[Optional[bool]]] = None,
                                is_heat_wave_cluster_attached: Optional[pulumi.Input[Optional[bool]]] = None,
                                is_up_to_date: Optional[pulumi.Input[Optional[bool]]] = None,
                                state: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMysqlDbSystemsResult]:
    """
    This data source provides the list of Mysql Db Systems in Oracle Cloud Infrastructure MySQL Database service.

    Get a list of DB Systems in the specified compartment.
    The default sort order is by timeUpdated, descending.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_mysql_db_systems = oci.Mysql.get_mysql_db_systems(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        db_system_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_analytics_cluster_attached=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_heat_wave_cluster_attached=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_up_to_date=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str configuration_id: The requested Configuration instance.
    :param str db_system_id: The DB System [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only the resource matching the given display name exactly.
    :param bool is_analytics_cluster_attached: DEPRECATED -- please use HeatWave API instead. If true, return only DB Systems with an Analytics Cluster attached, if false return only DB Systems with no Analytics Cluster attached. If not present, return all DB Systems.
    :param bool is_heat_wave_cluster_attached: If true, return only DB Systems with a HeatWave cluster attached, if false return only DB Systems with no HeatWave cluster attached. If not present, return all DB Systems.
    :param bool is_up_to_date: Filter instances if they are using the latest revision of the Configuration they are associated with.
    :param str state: DbSystem Lifecycle State
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetAgentDependencyResult',
    'AwaitableGetAgentDependencyResult',
    'get_agent_dependency',
    'get_agent_dependency_output',
]

@pulumi.output_type
class GetAgentDependencyResult:
    """
    A collection of values returned by getAgentDependency.
    """
    def __init__(__self__, agent_dependency_id=None, bucket=None, checksum=None, compartment_id=None, defined_tags=None, dependency_name=None, dependency_version=None, description=None, display_name=None, e_tag=None, freeform_tags=None, id=None, lifecycle_details=None, namespace=None, object=None, state=None, system_tags=None, time_created=None):
        if agent_dependency_id and not isinstance(agent_dependency_id, str):
            raise TypeError("Expected argument 'agent_dependency_id' to be a str")
        pulumi.set(__self__, "agent_dependency_id", agent_dependency_id)
        if bucket and not isinstance(bucket, str):
            raise TypeError("Expected argument 'bucket' to be a str")
        pulumi.set(__self__, "bucket", bucket)
        if checksum and not isinstance(checksum, str):
            raise TypeError("Expected argument 'checksum' to be a str")
        pulumi.set(__self__, "checksum", checksum)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if dependency_name and not isinstance(dependency_name, str):
            raise TypeError("Expected argument 'dependency_name' to be a str")
        pulumi.set(__self__, "dependency_name", dependency_name)
        if dependency_version and not isinstance(dependency_version, str):
            raise TypeError("Expected argument 'dependency_version' to be a str")
        pulumi.set(__self__, "dependency_version", dependency_version)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if e_tag and not isinstance(e_tag, str):
            raise TypeError("Expected argument 'e_tag' to be a str")
        pulumi.set(__self__, "e_tag", e_tag)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if object and not isinstance(object, str):
            raise TypeError("Expected argument 'object' to be a str")
        pulumi.set(__self__, "object", object)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="agentDependencyId")
    def agent_dependency_id(self) -> str:
        return pulumi.get(self, "agent_dependency_id")

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        Object storage bucket where the Agent dependency is uploaded.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def checksum(self) -> str:
        """
        The checksum associated with the dependency object returned by Object Storage.
        """
        return pulumi.get(self, "checksum")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="dependencyName")
    def dependency_name(self) -> str:
        """
        Name of the dependency type. This should match the whitelisted enum of dependency names.
        """
        return pulumi.get(self, "dependency_name")

    @property
    @pulumi.getter(name="dependencyVersion")
    def dependency_version(self) -> str:
        """
        Version of the Agent dependency.
        """
        return pulumi.get(self, "dependency_version")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description about the Agent dependency.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Display name of the Agent dependency.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="eTag")
    def e_tag(self) -> str:
        """
        The eTag associated with the dependency object returned by Object Storage.
        """
        return pulumi.get(self, "e_tag")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier that is immutable on creation.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        Object storage namespace associated with the customer's tenancy.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def object(self) -> str:
        """
        Name of the dependency object uploaded by the customer.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of AgentDependency.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time when the AgentDependency was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")


class AwaitableGetAgentDependencyResult(GetAgentDependencyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAgentDependencyResult(
            agent_dependency_id=self.agent_dependency_id,
            bucket=self.bucket,
            checksum=self.checksum,
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            dependency_name=self.dependency_name,
            dependency_version=self.dependency_version,
            description=self.description,
            display_name=self.display_name,
            e_tag=self.e_tag,
            freeform_tags=self.freeform_tags,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            namespace=self.namespace,
            object=self.object,
            state=self.state,
            system_tags=self.system_tags,
            time_created=self.time_created)


def get_agent_dependency(agent_dependency_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAgentDependencyResult:
    """
    This data source provides details about a specific Agent Dependency resource in Oracle Cloud Infrastructure Cloud Bridge service.

    Gets an AgentDependency by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_agent_dependency = oci.CloudBridge.get_agent_dependency(agent_dependency_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str agent_dependency_id: A unique AgentDependency identifier.
    """
    __args__ = dict()
    __args__['agentDependencyId'] = agent_dependency_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:CloudBridge/getAgentDependency:getAgentDependency', __args__, opts=opts, typ=GetAgentDependencyResult).value

    return AwaitableGetAgentDependencyResult(
        agent_dependency_id=__ret__.agent_dependency_id,
        bucket=__ret__.bucket,
        checksum=__ret__.checksum,
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        dependency_name=__ret__.dependency_name,
        dependency_version=__ret__.dependency_version,
        description=__ret__.description,
        display_name=__ret__.display_name,
        e_tag=__ret__.e_tag,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        lifecycle_details=__ret__.lifecycle_details,
        namespace=__ret__.namespace,
        object=__ret__.object,
        state=__ret__.state,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_agent_dependency)
def get_agent_dependency_output(agent_dependency_id: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAgentDependencyResult]:
    """
    This data source provides details about a specific Agent Dependency resource in Oracle Cloud Infrastructure Cloud Bridge service.

    Gets an AgentDependency by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_agent_dependency = oci.CloudBridge.get_agent_dependency(agent_dependency_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str agent_dependency_id: A unique AgentDependency identifier.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAccessRequestsResult',
    'AwaitableGetAccessRequestsResult',
    'get_access_requests',
    'get_access_requests_output',
]

@pulumi.output_type
class GetAccessRequestsResult:
    """
    A collection of values returned by getAccessRequests.
    """
    def __init__(__self__, access_request_collections=None, compartment_id=None, filters=None, id=None, resource_name=None, resource_type=None, state=None, time_end=None, time_start=None):
        if access_request_collections and not isinstance(access_request_collections, list):
            raise TypeError("Expected argument 'access_request_collections' to be a list")
        pulumi.set(__self__, "access_request_collections", access_request_collections)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if resource_name and not isinstance(resource_name, str):
            raise TypeError("Expected argument 'resource_name' to be a str")
        pulumi.set(__self__, "resource_name", resource_name)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_end and not isinstance(time_end, str):
            raise TypeError("Expected argument 'time_end' to be a str")
        pulumi.set(__self__, "time_end", time_end)
        if time_start and not isinstance(time_start, str):
            raise TypeError("Expected argument 'time_start' to be a str")
        pulumi.set(__self__, "time_start", time_start)

    @property
    @pulumi.getter(name="accessRequestCollections")
    def access_request_collections(self) -> Sequence['outputs.GetAccessRequestsAccessRequestCollectionResult']:
        """
        The list of access_request_collection.
        """
        return pulumi.get(self, "access_request_collections")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains the access request.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAccessRequestsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[str]:
        """
        The name of the target resource.
        """
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[str]:
        """
        resourceType for which the AccessRequest is applicable
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the AccessRequest.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> Optional[str]:
        return pulumi.get(self, "time_end")

    @property
    @pulumi.getter(name="timeStart")
    def time_start(self) -> Optional[str]:
        return pulumi.get(self, "time_start")


class AwaitableGetAccessRequestsResult(GetAccessRequestsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccessRequestsResult(
            access_request_collections=self.access_request_collections,
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            resource_name=self.resource_name,
            resource_type=self.resource_type,
            state=self.state,
            time_end=self.time_end,
            time_start=self.time_start)


def get_access_requests(compartment_id: Optional[str] = None,
                        filters: Optional[Sequence[pulumi.InputType['GetAccessRequestsFilterArgs']]] = None,
                        resource_name: Optional[str] = None,
                        resource_type: Optional[str] = None,
                        state: Optional[str] = None,
                        time_end: Optional[str] = None,
                        time_start: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccessRequestsResult:
    """
    This data source provides the list of Access Requests in Oracle Cloud Infrastructure Operator Access Control service.

    Lists all access requests in the compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_access_requests = oci.OperatorAccessControl.get_access_requests(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_end=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_start=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str resource_name: A filter to return only resources that match the given ResourceName.
    :param str resource_type: A filter to return only lists of resources that match the entire given service type.
    :param str state: A filter to return only resources whose lifecycleState matches the given AccessRequest lifecycleState.
    :param str time_end: Query start time in UTC in ISO 8601 format(inclusive). Example 2019-10-30T00:00:00Z (yyyy-MM-ddThh:mm:ssZ). timeIntervalStart and timeIntervalEnd parameters are used together.
    :param str time_start: Query start time in UTC in ISO 8601 format(inclusive). Example 2019-10-30T00:00:00Z (yyyy-MM-ddThh:mm:ssZ). timeIntervalStart and timeIntervalEnd parameters are used together.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['resourceName'] = resource_name
    __args__['resourceType'] = resource_type
    __args__['state'] = state
    __args__['timeEnd'] = time_end
    __args__['timeStart'] = time_start
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:OperatorAccessControl/getAccessRequests:getAccessRequests', __args__, opts=opts, typ=GetAccessRequestsResult).value

    return AwaitableGetAccessRequestsResult(
        access_request_collections=__ret__.access_request_collections,
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        resource_name=__ret__.resource_name,
        resource_type=__ret__.resource_type,
        state=__ret__.state,
        time_end=__ret__.time_end,
        time_start=__ret__.time_start)


@_utilities.lift_output_func(get_access_requests)
def get_access_requests_output(compartment_id: Optional[pulumi.Input[str]] = None,
                               filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAccessRequestsFilterArgs']]]]] = None,
                               resource_name: Optional[pulumi.Input[Optional[str]]] = None,
                               resource_type: Optional[pulumi.Input[Optional[str]]] = None,
                               state: Optional[pulumi.Input[Optional[str]]] = None,
                               time_end: Optional[pulumi.Input[Optional[str]]] = None,
                               time_start: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccessRequestsResult]:
    """
    This data source provides the list of Access Requests in Oracle Cloud Infrastructure Operator Access Control service.

    Lists all access requests in the compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_access_requests = oci.OperatorAccessControl.get_access_requests(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        resource_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_end=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_start=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str resource_name: A filter to return only resources that match the given ResourceName.
    :param str resource_type: A filter to return only lists of resources that match the entire given service type.
    :param str state: A filter to return only resources whose lifecycleState matches the given AccessRequest lifecycleState.
    :param str time_end: Query start time in UTC in ISO 8601 format(inclusive). Example 2019-10-30T00:00:00Z (yyyy-MM-ddThh:mm:ssZ). timeIntervalStart and timeIntervalEnd parameters are used together.
    :param str time_start: Query start time in UTC in ISO 8601 format(inclusive). Example 2019-10-30T00:00:00Z (yyyy-MM-ddThh:mm:ssZ). timeIntervalStart and timeIntervalEnd parameters are used together.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'DatasetDatasetFormatDetails',
    'DatasetDatasetFormatDetailsTextFileTypeMetadata',
    'DatasetDatasetSourceDetails',
    'DatasetInitialRecordGenerationConfiguration',
    'DatasetLabelSet',
    'DatasetLabelSetItem',
    'GetAnnotationFormatItemResult',
    'GetAnnotationFormatsAnnotationFormatCollectionResult',
    'GetAnnotationFormatsAnnotationFormatCollectionItemResult',
    'GetAnnotationFormatsFilterResult',
    'GetDatasetDatasetFormatDetailResult',
    'GetDatasetDatasetFormatDetailTextFileTypeMetadataResult',
    'GetDatasetDatasetSourceDetailResult',
    'GetDatasetInitialRecordGenerationConfigurationResult',
    'GetDatasetLabelSetResult',
    'GetDatasetLabelSetItemResult',
    'GetDatasetsDatasetCollectionResult',
    'GetDatasetsDatasetCollectionItemResult',
    'GetDatasetsDatasetCollectionItemDatasetFormatDetailResult',
    'GetDatasetsDatasetCollectionItemDatasetFormatDetailTextFileTypeMetadataResult',
    'GetDatasetsDatasetCollectionItemDatasetSourceDetailResult',
    'GetDatasetsDatasetCollectionItemInitialRecordGenerationConfigurationResult',
    'GetDatasetsDatasetCollectionItemLabelSetResult',
    'GetDatasetsDatasetCollectionItemLabelSetItemResult',
    'GetDatasetsFilterResult',
]

@pulumi.output_type
class DatasetDatasetFormatDetails(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "formatType":
            suggest = "format_type"
        elif key == "textFileTypeMetadata":
            suggest = "text_file_type_metadata"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DatasetDatasetFormatDetails. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DatasetDatasetFormatDetails.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DatasetDatasetFormatDetails.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 format_type: str,
                 text_file_type_metadata: Optional['outputs.DatasetDatasetFormatDetailsTextFileTypeMetadata'] = None):
        """
        :param str format_type: It defines the format type of text files.
        :param 'DatasetDatasetFormatDetailsTextFileTypeMetadataArgs' text_file_type_metadata: Metadata for files with text content.
        """
        pulumi.set(__self__, "format_type", format_type)
        if text_file_type_metadata is not None:
            pulumi.set(__self__, "text_file_type_metadata", text_file_type_metadata)

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> str:
        """
        It defines the format type of text files.
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="textFileTypeMetadata")
    def text_file_type_metadata(self) -> Optional['outputs.DatasetDatasetFormatDetailsTextFileTypeMetadata']:
        """
        Metadata for files with text content.
        """
        return pulumi.get(self, "text_file_type_metadata")


@pulumi.output_type
class DatasetDatasetFormatDetailsTextFileTypeMetadata(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "columnIndex":
            suggest = "column_index"
        elif key == "formatType":
            suggest = "format_type"
        elif key == "columnDelimiter":
            suggest = "column_delimiter"
        elif key == "columnName":
            suggest = "column_name"
        elif key == "escapeCharacter":
            suggest = "escape_character"
        elif key == "lineDelimiter":
            suggest = "line_delimiter"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DatasetDatasetFormatDetailsTextFileTypeMetadata. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DatasetDatasetFormatDetailsTextFileTypeMetadata.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DatasetDatasetFormatDetailsTextFileTypeMetadata.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 column_index: int,
                 format_type: str,
                 column_delimiter: Optional[str] = None,
                 column_name: Optional[str] = None,
                 escape_character: Optional[str] = None,
                 line_delimiter: Optional[str] = None):
        """
        :param int column_index: The index of a selected column. This is a zero-based index.
        :param str format_type: It defines the format type of text files.
        :param str column_delimiter: A column delimiter
        :param str column_name: The name of a selected column.
        :param str escape_character: An escape character.
        :param str line_delimiter: A line delimiter.
        """
        pulumi.set(__self__, "column_index", column_index)
        pulumi.set(__self__, "format_type", format_type)
        if column_delimiter is not None:
            pulumi.set(__self__, "column_delimiter", column_delimiter)
        if column_name is not None:
            pulumi.set(__self__, "column_name", column_name)
        if escape_character is not None:
            pulumi.set(__self__, "escape_character", escape_character)
        if line_delimiter is not None:
            pulumi.set(__self__, "line_delimiter", line_delimiter)

    @property
    @pulumi.getter(name="columnIndex")
    def column_index(self) -> int:
        """
        The index of a selected column. This is a zero-based index.
        """
        return pulumi.get(self, "column_index")

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> str:
        """
        It defines the format type of text files.
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="columnDelimiter")
    def column_delimiter(self) -> Optional[str]:
        """
        A column delimiter
        """
        return pulumi.get(self, "column_delimiter")

    @property
    @pulumi.getter(name="columnName")
    def column_name(self) -> Optional[str]:
        """
        The name of a selected column.
        """
        return pulumi.get(self, "column_name")

    @property
    @pulumi.getter(name="escapeCharacter")
    def escape_character(self) -> Optional[str]:
        """
        An escape character.
        """
        return pulumi.get(self, "escape_character")

    @property
    @pulumi.getter(name="lineDelimiter")
    def line_delimiter(self) -> Optional[str]:
        """
        A line delimiter.
        """
        return pulumi.get(self, "line_delimiter")


@pulumi.output_type
class DatasetDatasetSourceDetails(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourceType":
            suggest = "source_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DatasetDatasetSourceDetails. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DatasetDatasetSourceDetails.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DatasetDatasetSourceDetails.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket: str,
                 namespace: str,
                 source_type: str,
                 prefix: Optional[str] = None):
        """
        :param str bucket: The object storage bucket that contains the dataset data source.
        :param str namespace: The namespace of the bucket that contains the dataset data source.
        :param str source_type: The source type. OBJECT_STORAGE allows the user to describe where in object storage the dataset is.
        :param str prefix: A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "source_type", source_type)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        The object storage bucket that contains the dataset data source.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        The namespace of the bucket that contains the dataset data source.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> str:
        """
        The source type. OBJECT_STORAGE allows the user to describe where in object storage the dataset is.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def prefix(self) -> Optional[str]:
        """
        A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.
        """
        return pulumi.get(self, "prefix")


@pulumi.output_type
class DatasetInitialRecordGenerationConfiguration(dict):
    def __init__(__self__):
        pass


@pulumi.output_type
class DatasetLabelSet(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.DatasetLabelSetItem']):
        """
        :param Sequence['DatasetLabelSetItemArgs'] items: An ordered collection of labels that are unique by name.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.DatasetLabelSetItem']:
        """
        An ordered collection of labels that are unique by name.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class DatasetLabelSetItem(dict):
    def __init__(__self__, *,
                 name: str):
        """
        :param str name: An unique name for a label within its dataset.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        An unique name for a label within its dataset.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetAnnotationFormatItemResult(dict):
    def __init__(__self__, *,
                 name: str):
        """
        :param str name: A unique name for the target AnnotationFormat for the Dataset.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A unique name for the target AnnotationFormat for the Dataset.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetAnnotationFormatsAnnotationFormatCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetAnnotationFormatsAnnotationFormatCollectionItemResult']):
        """
        :param Sequence['GetAnnotationFormatsAnnotationFormatCollectionItemArgs'] items: List of annotation formats.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetAnnotationFormatsAnnotationFormatCollectionItemResult']:
        """
        List of annotation formats.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetAnnotationFormatsAnnotationFormatCollectionItemResult(dict):
    def __init__(__self__, *,
                 name: str):
        """
        :param str name: A unique name for the target AnnotationFormat for the Dataset.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A unique name for the target AnnotationFormat for the Dataset.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetAnnotationFormatsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: A unique name for the target AnnotationFormat for the Dataset.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A unique name for the target AnnotationFormat for the Dataset.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetDatasetDatasetFormatDetailResult(dict):
    def __init__(__self__, *,
                 format_type: str,
                 text_file_type_metadatas: Sequence['outputs.GetDatasetDatasetFormatDetailTextFileTypeMetadataResult']):
        """
        :param str format_type: It defines the format type of text files.
        :param Sequence['GetDatasetDatasetFormatDetailTextFileTypeMetadataArgs'] text_file_type_metadatas: Metadata for files with text content.
        """
        pulumi.set(__self__, "format_type", format_type)
        pulumi.set(__self__, "text_file_type_metadatas", text_file_type_metadatas)

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> str:
        """
        It defines the format type of text files.
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="textFileTypeMetadatas")
    def text_file_type_metadatas(self) -> Sequence['outputs.GetDatasetDatasetFormatDetailTextFileTypeMetadataResult']:
        """
        Metadata for files with text content.
        """
        return pulumi.get(self, "text_file_type_metadatas")


@pulumi.output_type
class GetDatasetDatasetFormatDetailTextFileTypeMetadataResult(dict):
    def __init__(__self__, *,
                 column_delimiter: str,
                 column_index: int,
                 column_name: str,
                 escape_character: str,
                 format_type: str,
                 line_delimiter: str):
        """
        :param str column_delimiter: A column delimiter
        :param int column_index: The index of a selected column. This is a zero-based index.
        :param str column_name: The name of a selected column.
        :param str escape_character: An escape character.
        :param str format_type: It defines the format type of text files.
        :param str line_delimiter: A line delimiter.
        """
        pulumi.set(__self__, "column_delimiter", column_delimiter)
        pulumi.set(__self__, "column_index", column_index)
        pulumi.set(__self__, "column_name", column_name)
        pulumi.set(__self__, "escape_character", escape_character)
        pulumi.set(__self__, "format_type", format_type)
        pulumi.set(__self__, "line_delimiter", line_delimiter)

    @property
    @pulumi.getter(name="columnDelimiter")
    def column_delimiter(self) -> str:
        """
        A column delimiter
        """
        return pulumi.get(self, "column_delimiter")

    @property
    @pulumi.getter(name="columnIndex")
    def column_index(self) -> int:
        """
        The index of a selected column. This is a zero-based index.
        """
        return pulumi.get(self, "column_index")

    @property
    @pulumi.getter(name="columnName")
    def column_name(self) -> str:
        """
        The name of a selected column.
        """
        return pulumi.get(self, "column_name")

    @property
    @pulumi.getter(name="escapeCharacter")
    def escape_character(self) -> str:
        """
        An escape character.
        """
        return pulumi.get(self, "escape_character")

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> str:
        """
        It defines the format type of text files.
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="lineDelimiter")
    def line_delimiter(self) -> str:
        """
        A line delimiter.
        """
        return pulumi.get(self, "line_delimiter")


@pulumi.output_type
class GetDatasetDatasetSourceDetailResult(dict):
    def __init__(__self__, *,
                 bucket: str,
                 namespace: str,
                 prefix: str,
                 source_type: str):
        """
        :param str bucket: The object storage bucket that contains the dataset data source.
        :param str namespace: The namespace of the bucket that contains the dataset data source.
        :param str prefix: A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.
        :param str source_type: The source type. OBJECT_STORAGE allows the user to describe where in object storage the dataset is.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "prefix", prefix)
        pulumi.set(__self__, "source_type", source_type)

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        The object storage bucket that contains the dataset data source.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        The namespace of the bucket that contains the dataset data source.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def prefix(self) -> str:
        """
        A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.
        """
        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> str:
        """
        The source type. OBJECT_STORAGE allows the user to describe where in object storage the dataset is.
        """
        return pulumi.get(self, "source_type")


@pulumi.output_type
class GetDatasetInitialRecordGenerationConfigurationResult(dict):
    def __init__(__self__):
        pass


@pulumi.output_type
class GetDatasetLabelSetResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetDatasetLabelSetItemResult']):
        """
        :param Sequence['GetDatasetLabelSetItemArgs'] items: An ordered collection of labels that are unique by name.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetDatasetLabelSetItemResult']:
        """
        An ordered collection of labels that are unique by name.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetDatasetLabelSetItemResult(dict):
    def __init__(__self__, *,
                 name: str):
        """
        :param str name: An unique name for a label within its dataset.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        An unique name for a label within its dataset.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetDatasetsDatasetCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetDatasetsDatasetCollectionItemResult']):
        """
        :param Sequence['GetDatasetsDatasetCollectionItemArgs'] items: An ordered collection of labels that are unique by name.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemResult']:
        """
        An ordered collection of labels that are unique by name.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetDatasetsDatasetCollectionItemResult(dict):
    def __init__(__self__, *,
                 annotation_format: str,
                 compartment_id: str,
                 dataset_format_details: Sequence['outputs.GetDatasetsDatasetCollectionItemDatasetFormatDetailResult'],
                 dataset_source_details: Sequence['outputs.GetDatasetsDatasetCollectionItemDatasetSourceDetailResult'],
                 defined_tags: Mapping[str, Any],
                 description: str,
                 display_name: str,
                 freeform_tags: Mapping[str, Any],
                 id: str,
                 initial_record_generation_configurations: Sequence['outputs.GetDatasetsDatasetCollectionItemInitialRecordGenerationConfigurationResult'],
                 label_sets: Sequence['outputs.GetDatasetsDatasetCollectionItemLabelSetResult'],
                 labeling_instructions: str,
                 lifecycle_details: str,
                 state: str,
                 time_created: str,
                 time_updated: str):
        """
        :param str annotation_format: A filter to return only resources that match the entire annotation format given.
        :param str compartment_id: The ID of the compartment in which to list resources.
        :param Sequence['GetDatasetsDatasetCollectionItemDatasetFormatDetailArgs'] dataset_format_details: It specifies how to process the data. Supported formats include DOCUMENT, IMAGE, and TEXT.
        :param Sequence['GetDatasetsDatasetCollectionItemDatasetSourceDetailArgs'] dataset_source_details: This allows the customer to specify the source of the dataset.
        :param Mapping[str, Any] defined_tags: The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: `{"foo-namespace": {"bar-key": "value"}}`
        :param str description: A user provided description of the dataset
        :param str display_name: A filter to return only resources that match the entire display name given.
        :param Mapping[str, Any] freeform_tags: A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: `{"bar-key": "value"}`
        :param str id: Unique Dataset OCID
        :param Sequence['GetDatasetsDatasetCollectionItemInitialRecordGenerationConfigurationArgs'] initial_record_generation_configurations: The initial generate records configuration. It generates records from the dataset's source.
        :param Sequence['GetDatasetsDatasetCollectionItemLabelSetArgs'] label_sets: An ordered collection of labels that are unique by name.
        :param str labeling_instructions: The labeling instructions for human labelers in rich text format
        :param str lifecycle_details: A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in FAILED or NEEDS_ATTENTION state.
        :param str state: A filter to return only resources whose lifecycleState matches this query param.
        :param str time_created: The date and time the resource was created, in the timestamp format defined by RFC3339.
        :param str time_updated: The date and time the resource was last updated, in the timestamp format defined by RFC3339.
        """
        pulumi.set(__self__, "annotation_format", annotation_format)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "dataset_format_details", dataset_format_details)
        pulumi.set(__self__, "dataset_source_details", dataset_source_details)
        pulumi.set(__self__, "defined_tags", defined_tags)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "initial_record_generation_configurations", initial_record_generation_configurations)
        pulumi.set(__self__, "label_sets", label_sets)
        pulumi.set(__self__, "labeling_instructions", labeling_instructions)
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "time_created", time_created)
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="annotationFormat")
    def annotation_format(self) -> str:
        """
        A filter to return only resources that match the entire annotation format given.
        """
        return pulumi.get(self, "annotation_format")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The ID of the compartment in which to list resources.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="datasetFormatDetails")
    def dataset_format_details(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemDatasetFormatDetailResult']:
        """
        It specifies how to process the data. Supported formats include DOCUMENT, IMAGE, and TEXT.
        """
        return pulumi.get(self, "dataset_format_details")

    @property
    @pulumi.getter(name="datasetSourceDetails")
    def dataset_source_details(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemDatasetSourceDetailResult']:
        """
        This allows the customer to specify the source of the dataset.
        """
        return pulumi.get(self, "dataset_source_details")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: `{"foo-namespace": {"bar-key": "value"}}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A user provided description of the dataset
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A filter to return only resources that match the entire display name given.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique Dataset OCID
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="initialRecordGenerationConfigurations")
    def initial_record_generation_configurations(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemInitialRecordGenerationConfigurationResult']:
        """
        The initial generate records configuration. It generates records from the dataset's source.
        """
        return pulumi.get(self, "initial_record_generation_configurations")

    @property
    @pulumi.getter(name="labelSets")
    def label_sets(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemLabelSetResult']:
        """
        An ordered collection of labels that are unique by name.
        """
        return pulumi.get(self, "label_sets")

    @property
    @pulumi.getter(name="labelingInstructions")
    def labeling_instructions(self) -> str:
        """
        The labeling instructions for human labelers in rich text format
        """
        return pulumi.get(self, "labeling_instructions")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in FAILED or NEEDS_ATTENTION state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        A filter to return only resources whose lifecycleState matches this query param.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the resource was created, in the timestamp format defined by RFC3339.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the resource was last updated, in the timestamp format defined by RFC3339.
        """
        return pulumi.get(self, "time_updated")


@pulumi.output_type
class GetDatasetsDatasetCollectionItemDatasetFormatDetailResult(dict):
    def __init__(__self__, *,
                 format_type: str,
                 text_file_type_metadatas: Sequence['outputs.GetDatasetsDatasetCollectionItemDatasetFormatDetailTextFileTypeMetadataResult']):
        """
        :param str format_type: It defines the format type of text files.
        :param Sequence['GetDatasetsDatasetCollectionItemDatasetFormatDetailTextFileTypeMetadataArgs'] text_file_type_metadatas: Metadata for files with text content.
        """
        pulumi.set(__self__, "format_type", format_type)
        pulumi.set(__self__, "text_file_type_metadatas", text_file_type_metadatas)

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> str:
        """
        It defines the format type of text files.
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="textFileTypeMetadatas")
    def text_file_type_metadatas(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemDatasetFormatDetailTextFileTypeMetadataResult']:
        """
        Metadata for files with text content.
        """
        return pulumi.get(self, "text_file_type_metadatas")


@pulumi.output_type
class GetDatasetsDatasetCollectionItemDatasetFormatDetailTextFileTypeMetadataResult(dict):
    def __init__(__self__, *,
                 column_delimiter: str,
                 column_index: int,
                 column_name: str,
                 escape_character: str,
                 format_type: str,
                 line_delimiter: str):
        """
        :param str column_delimiter: A column delimiter
        :param int column_index: The index of a selected column. This is a zero-based index.
        :param str column_name: The name of a selected column.
        :param str escape_character: An escape character.
        :param str format_type: It defines the format type of text files.
        :param str line_delimiter: A line delimiter.
        """
        pulumi.set(__self__, "column_delimiter", column_delimiter)
        pulumi.set(__self__, "column_index", column_index)
        pulumi.set(__self__, "column_name", column_name)
        pulumi.set(__self__, "escape_character", escape_character)
        pulumi.set(__self__, "format_type", format_type)
        pulumi.set(__self__, "line_delimiter", line_delimiter)

    @property
    @pulumi.getter(name="columnDelimiter")
    def column_delimiter(self) -> str:
        """
        A column delimiter
        """
        return pulumi.get(self, "column_delimiter")

    @property
    @pulumi.getter(name="columnIndex")
    def column_index(self) -> int:
        """
        The index of a selected column. This is a zero-based index.
        """
        return pulumi.get(self, "column_index")

    @property
    @pulumi.getter(name="columnName")
    def column_name(self) -> str:
        """
        The name of a selected column.
        """
        return pulumi.get(self, "column_name")

    @property
    @pulumi.getter(name="escapeCharacter")
    def escape_character(self) -> str:
        """
        An escape character.
        """
        return pulumi.get(self, "escape_character")

    @property
    @pulumi.getter(name="formatType")
    def format_type(self) -> str:
        """
        It defines the format type of text files.
        """
        return pulumi.get(self, "format_type")

    @property
    @pulumi.getter(name="lineDelimiter")
    def line_delimiter(self) -> str:
        """
        A line delimiter.
        """
        return pulumi.get(self, "line_delimiter")


@pulumi.output_type
class GetDatasetsDatasetCollectionItemDatasetSourceDetailResult(dict):
    def __init__(__self__, *,
                 bucket: str,
                 namespace: str,
                 prefix: str,
                 source_type: str):
        """
        :param str bucket: The object storage bucket that contains the dataset data source.
        :param str namespace: The namespace of the bucket that contains the dataset data source.
        :param str prefix: A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.
        :param str source_type: The source type. OBJECT_STORAGE allows the user to describe where in object storage the dataset is.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "prefix", prefix)
        pulumi.set(__self__, "source_type", source_type)

    @property
    @pulumi.getter
    def bucket(self) -> str:
        """
        The object storage bucket that contains the dataset data source.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        The namespace of the bucket that contains the dataset data source.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def prefix(self) -> str:
        """
        A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.
        """
        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> str:
        """
        The source type. OBJECT_STORAGE allows the user to describe where in object storage the dataset is.
        """
        return pulumi.get(self, "source_type")


@pulumi.output_type
class GetDatasetsDatasetCollectionItemInitialRecordGenerationConfigurationResult(dict):
    def __init__(__self__):
        pass


@pulumi.output_type
class GetDatasetsDatasetCollectionItemLabelSetResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetDatasetsDatasetCollectionItemLabelSetItemResult']):
        """
        :param Sequence['GetDatasetsDatasetCollectionItemLabelSetItemArgs'] items: An ordered collection of labels that are unique by name.
        """
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetDatasetsDatasetCollectionItemLabelSetItemResult']:
        """
        An ordered collection of labels that are unique by name.
        """
        return pulumi.get(self, "items")


@pulumi.output_type
class GetDatasetsDatasetCollectionItemLabelSetItemResult(dict):
    def __init__(__self__, *,
                 name: str):
        """
        :param str name: An unique name for a label within its dataset.
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        An unique name for a label within its dataset.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetDatasetsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: An unique name for a label within its dataset.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        An unique name for a label within its dataset.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVaultsResult',
    'AwaitableGetVaultsResult',
    'get_vaults',
    'get_vaults_output',
]

@pulumi.output_type
class GetVaultsResult:
    """
    A collection of values returned by getVaults.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, vaults=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if vaults and not isinstance(vaults, list):
            raise TypeError("Expected argument 'vaults' to be a list")
        pulumi.set(__self__, "vaults", vaults)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains a particular vault.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetVaultsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def vaults(self) -> Sequence['outputs.GetVaultsVaultResult']:
        """
        The list of vaults.
        """
        return pulumi.get(self, "vaults")


class AwaitableGetVaultsResult(GetVaultsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVaultsResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            vaults=self.vaults)


def get_vaults(compartment_id: Optional[str] = None,
               filters: Optional[Sequence[pulumi.InputType['GetVaultsFilterArgs']]] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVaultsResult:
    """
    This data source provides the list of Vaults in Oracle Cloud Infrastructure Kms service.

    Lists the vaults in the specified compartment.

    As a provisioning operation, this call is subject to a Key Management limit that applies to
    the total number of requests across all provisioning read operations. Key Management might
    throttle this call to reject an otherwise valid request when the total rate of provisioning
    read operations exceeds 10 requests per second for a given tenancy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vaults = oci.Kms.get_vaults(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Kms/getVaults:getVaults', __args__, opts=opts, typ=GetVaultsResult).value

    return AwaitableGetVaultsResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        vaults=__ret__.vaults)


@_utilities.lift_output_func(get_vaults)
def get_vaults_output(compartment_id: Optional[pulumi.Input[str]] = None,
                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetVaultsFilterArgs']]]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVaultsResult]:
    """
    This data source provides the list of Vaults in Oracle Cloud Infrastructure Kms service.

    Lists the vaults in the specified compartment.

    As a provisioning operation, this call is subject to a Key Management limit that applies to
    the total number of requests across all provisioning read operations. Key Management might
    throttle this call to reject an otherwise valid request when the total rate of provisioning
    read operations exceeds 10 requests per second for a given tenancy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vaults = oci.Kms.get_vaults(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDiscoveryJobResult',
    'AwaitableGetDiscoveryJobResult',
    'get_discovery_job',
    'get_discovery_job_output',
]

@pulumi.output_type
class GetDiscoveryJobResult:
    """
    A collection of values returned by getDiscoveryJob.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, discovery_client=None, discovery_details=None, discovery_job_id=None, discovery_type=None, freeform_tags=None, id=None, should_propagate_tags_to_discovered_resources=None, state=None, status=None, status_message=None, system_tags=None, tenant_id=None, time_updated=None, user_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if discovery_client and not isinstance(discovery_client, str):
            raise TypeError("Expected argument 'discovery_client' to be a str")
        pulumi.set(__self__, "discovery_client", discovery_client)
        if discovery_details and not isinstance(discovery_details, list):
            raise TypeError("Expected argument 'discovery_details' to be a list")
        pulumi.set(__self__, "discovery_details", discovery_details)
        if discovery_job_id and not isinstance(discovery_job_id, str):
            raise TypeError("Expected argument 'discovery_job_id' to be a str")
        pulumi.set(__self__, "discovery_job_id", discovery_job_id)
        if discovery_type and not isinstance(discovery_type, str):
            raise TypeError("Expected argument 'discovery_type' to be a str")
        pulumi.set(__self__, "discovery_type", discovery_type)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if should_propagate_tags_to_discovered_resources and not isinstance(should_propagate_tags_to_discovered_resources, bool):
            raise TypeError("Expected argument 'should_propagate_tags_to_discovered_resources' to be a bool")
        pulumi.set(__self__, "should_propagate_tags_to_discovered_resources", should_propagate_tags_to_discovered_resources)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if status_message and not isinstance(status_message, str):
            raise TypeError("Expected argument 'status_message' to be a str")
        pulumi.set(__self__, "status_message", status_message)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the Compartment
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="discoveryClient")
    def discovery_client(self) -> str:
        """
        Client who submits discovery job.
        """
        return pulumi.get(self, "discovery_client")

    @property
    @pulumi.getter(name="discoveryDetails")
    def discovery_details(self) -> Sequence['outputs.GetDiscoveryJobDiscoveryDetailResult']:
        """
        The request of DiscoveryJob Resource details.
        """
        return pulumi.get(self, "discovery_details")

    @property
    @pulumi.getter(name="discoveryJobId")
    def discovery_job_id(self) -> str:
        return pulumi.get(self, "discovery_job_id")

    @property
    @pulumi.getter(name="discoveryType")
    def discovery_type(self) -> str:
        """
        Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
        """
        return pulumi.get(self, "discovery_type")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of Discovery job
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="shouldPropagateTagsToDiscoveredResources")
    def should_propagate_tags_to_discovered_resources(self) -> bool:
        return pulumi.get(self, "should_propagate_tags_to_discovered_resources")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the DiscoveryJob Resource.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Specifies the status of the discovery job
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> str:
        """
        The short summary of the status of the discovery job
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The OCID of Tenant
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the discovery Job was updated.
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The OCID of user in which the job is submitted
        """
        return pulumi.get(self, "user_id")


class AwaitableGetDiscoveryJobResult(GetDiscoveryJobResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDiscoveryJobResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            discovery_client=self.discovery_client,
            discovery_details=self.discovery_details,
            discovery_job_id=self.discovery_job_id,
            discovery_type=self.discovery_type,
            freeform_tags=self.freeform_tags,
            id=self.id,
            should_propagate_tags_to_discovered_resources=self.should_propagate_tags_to_discovered_resources,
            state=self.state,
            status=self.status,
            status_message=self.status_message,
            system_tags=self.system_tags,
            tenant_id=self.tenant_id,
            time_updated=self.time_updated,
            user_id=self.user_id)


def get_discovery_job(discovery_job_id: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDiscoveryJobResult:
    """
    This data source provides details about a specific Discovery Job resource in Oracle Cloud Infrastructure Stack Monitoring service.

    API to get the details of discovery Job by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_discovery_job = oci.StackMonitoring.get_discovery_job(discovery_job_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str discovery_job_id: The Discovery Job ID
    """
    __args__ = dict()
    __args__['discoveryJobId'] = discovery_job_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:StackMonitoring/getDiscoveryJob:getDiscoveryJob', __args__, opts=opts, typ=GetDiscoveryJobResult).value

    return AwaitableGetDiscoveryJobResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        discovery_client=__ret__.discovery_client,
        discovery_details=__ret__.discovery_details,
        discovery_job_id=__ret__.discovery_job_id,
        discovery_type=__ret__.discovery_type,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        should_propagate_tags_to_discovered_resources=__ret__.should_propagate_tags_to_discovered_resources,
        state=__ret__.state,
        status=__ret__.status,
        status_message=__ret__.status_message,
        system_tags=__ret__.system_tags,
        tenant_id=__ret__.tenant_id,
        time_updated=__ret__.time_updated,
        user_id=__ret__.user_id)


@_utilities.lift_output_func(get_discovery_job)
def get_discovery_job_output(discovery_job_id: Optional[pulumi.Input[str]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDiscoveryJobResult]:
    """
    This data source provides details about a specific Discovery Job resource in Oracle Cloud Infrastructure Stack Monitoring service.

    API to get the details of discovery Job by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_discovery_job = oci.StackMonitoring.get_discovery_job(discovery_job_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str discovery_job_id: The Discovery Job ID
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .bucket import *
from .get_bucket import *
from .get_bucket_summaries import *
from .get_namespace import *
from .get_namespace_metadata import *
from .get_object import *
from .get_object_head import *
from .get_object_lifecycle_policy import *
from .get_object_versions import *
from .get_objects import *
from .get_preauthrequest import *
from .get_preauthrequests import *
from .get_replication_policies import *
from .get_replication_policy import *
from .get_replication_sources import *
from .namespace_metadata import *
from .object_lifecycle_policy import *
from .preauthrequest import *
from .replication_policy import *
from .storage_object import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PathRouteSetArgs', 'PathRouteSet']

@pulumi.input_type
class PathRouteSetArgs:
    def __init__(__self__, *,
                 load_balancer_id: pulumi.Input[str],
                 path_routes: pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a PathRouteSet resource.
        :param pulumi.Input[str] load_balancer_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        :param pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]] path_routes: (Updatable) The set of path route rules.
        :param pulumi.Input[str] name: The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        """
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        pulumi.set(__self__, "path_routes", path_routes)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="pathRoutes")
    def path_routes(self) -> pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]]:
        """
        (Updatable) The set of path route rules.
        """
        return pulumi.get(self, "path_routes")

    @path_routes.setter
    def path_routes(self, value: pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]]):
        pulumi.set(self, "path_routes", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _PathRouteSetState:
    def __init__(__self__, *,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path_routes: Optional[pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PathRouteSet resources.
        :param pulumi.Input[str] load_balancer_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        :param pulumi.Input[str] name: The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        :param pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]] path_routes: (Updatable) The set of path route rules.
        """
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path_routes is not None:
            pulumi.set(__self__, "path_routes", path_routes)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="pathRoutes")
    def path_routes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]]]:
        """
        (Updatable) The set of path route rules.
        """
        return pulumi.get(self, "path_routes")

    @path_routes.setter
    def path_routes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PathRouteSetPathRouteArgs']]]]):
        pulumi.set(self, "path_routes", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


class PathRouteSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path_routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PathRouteSetPathRouteArgs']]]]] = None,
                 __props__=None):
        """
        This resource provides the Path Route Set resource in Oracle Cloud Infrastructure Load Balancer service.

        Adds a path route set to a load balancer. For more information, see
        [Managing Request Routing](https://docs.cloud.oracle.com/iaas/Content/Balance/Tasks/managingrequest.htm).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_path_route_set = oci.load_balancer.PathRouteSet("testPathRouteSet",
            load_balancer_id=oci_load_balancer_load_balancer["test_load_balancer"]["id"],
            path_routes=[oci.load_balancer.PathRouteSetPathRouteArgs(
                backend_set_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path_match_type=oci.load_balancer.PathRouteSetPathRoutePathMatchTypeArgs(
                    match_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
            )])
        ```

        ## Import

        PathRouteSets can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:LoadBalancer/pathRouteSet:PathRouteSet test_path_route_set "loadBalancers/{loadBalancerId}/pathRouteSets/{pathRouteSetName}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] load_balancer_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        :param pulumi.Input[str] name: The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PathRouteSetPathRouteArgs']]]] path_routes: (Updatable) The set of path route rules.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PathRouteSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Path Route Set resource in Oracle Cloud Infrastructure Load Balancer service.

        Adds a path route set to a load balancer. For more information, see
        [Managing Request Routing](https://docs.cloud.oracle.com/iaas/Content/Balance/Tasks/managingrequest.htm).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_path_route_set = oci.load_balancer.PathRouteSet("testPathRouteSet",
            load_balancer_id=oci_load_balancer_load_balancer["test_load_balancer"]["id"],
            path_routes=[oci.load_balancer.PathRouteSetPathRouteArgs(
                backend_set_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path_match_type=oci.load_balancer.PathRouteSetPathRoutePathMatchTypeArgs(
                    match_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
            )])
        ```

        ## Import

        PathRouteSets can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:LoadBalancer/pathRouteSet:PathRouteSet test_path_route_set "loadBalancers/{loadBalancerId}/pathRouteSets/{pathRouteSetName}"
        ```

        :param str resource_name: The name of the resource.
        :param PathRouteSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PathRouteSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path_routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PathRouteSetPathRouteArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PathRouteSetArgs.__new__(PathRouteSetArgs)

            if load_balancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'load_balancer_id'")
            __props__.__dict__["load_balancer_id"] = load_balancer_id
            __props__.__dict__["name"] = name
            if path_routes is None and not opts.urn:
                raise TypeError("Missing required property 'path_routes'")
            __props__.__dict__["path_routes"] = path_routes
            __props__.__dict__["state"] = None
        super(PathRouteSet, __self__).__init__(
            'oci:LoadBalancer/pathRouteSet:PathRouteSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            load_balancer_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            path_routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PathRouteSetPathRouteArgs']]]]] = None,
            state: Optional[pulumi.Input[str]] = None) -> 'PathRouteSet':
        """
        Get an existing PathRouteSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] load_balancer_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        :param pulumi.Input[str] name: The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PathRouteSetPathRouteArgs']]]] path_routes: (Updatable) The set of path route rules.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PathRouteSetState.__new__(_PathRouteSetState)

        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["name"] = name
        __props__.__dict__["path_routes"] = path_routes
        __props__.__dict__["state"] = state
        return PathRouteSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to add the path route set to.
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name for this set of path route rules. It must be unique and it cannot be changed. Avoid entering confidential information.  Example: `example_path_route_set`
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="pathRoutes")
    def path_routes(self) -> pulumi.Output[Sequence['outputs.PathRouteSetPathRoute']]:
        """
        (Updatable) The set of path route rules.
        """
        return pulumi.get(self, "path_routes")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ImportStandardTagsManagementArgs', 'ImportStandardTagsManagement']

@pulumi.input_type
class ImportStandardTagsManagementArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 standard_tag_namespace_name: pulumi.Input[str]):
        """
        The set of arguments for constructing a ImportStandardTagsManagement resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        :param pulumi.Input[str] standard_tag_namespace_name: The name of standard tag namespace that will be imported in bulk 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "standard_tag_namespace_name", standard_tag_namespace_name)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="standardTagNamespaceName")
    def standard_tag_namespace_name(self) -> pulumi.Input[str]:
        """
        The name of standard tag namespace that will be imported in bulk 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "standard_tag_namespace_name")

    @standard_tag_namespace_name.setter
    def standard_tag_namespace_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "standard_tag_namespace_name", value)


@pulumi.input_type
class _ImportStandardTagsManagementState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 standard_tag_namespace_name: Optional[pulumi.Input[str]] = None,
                 work_request_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ImportStandardTagsManagement resources.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        :param pulumi.Input[str] standard_tag_namespace_name: The name of standard tag namespace that will be imported in bulk 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if standard_tag_namespace_name is not None:
            pulumi.set(__self__, "standard_tag_namespace_name", standard_tag_namespace_name)
        if work_request_id is not None:
            pulumi.set(__self__, "work_request_id", work_request_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="standardTagNamespaceName")
    def standard_tag_namespace_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of standard tag namespace that will be imported in bulk 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "standard_tag_namespace_name")

    @standard_tag_namespace_name.setter
    def standard_tag_namespace_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "standard_tag_namespace_name", value)

    @property
    @pulumi.getter(name="workRequestId")
    def work_request_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "work_request_id")

    @work_request_id.setter
    def work_request_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "work_request_id", value)


class ImportStandardTagsManagement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 standard_tag_namespace_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Import Standard Tags Management resource in Oracle Cloud Infrastructure Identity service.

        OCI will release Tag Namespaces that our customers can import.
        These Tag Namespaces will provide Tags for our customers and Partners to provide consistency and enable data reporting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_import_standard_tags_management = oci.identity.ImportStandardTagsManagement("testImportStandardTagsManagement",
            compartment_id=var["compartment_id"],
            standard_tag_namespace_name=oci_identity_tag_namespace["test_tag_namespace"]["name"])
        ```

        ## Import

        ImportStandardTagsManagement can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Identity/importStandardTagsManagement:ImportStandardTagsManagement test_import_standard_tags_management "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        :param pulumi.Input[str] standard_tag_namespace_name: The name of standard tag namespace that will be imported in bulk 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ImportStandardTagsManagementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Import Standard Tags Management resource in Oracle Cloud Infrastructure Identity service.

        OCI will release Tag Namespaces that our customers can import.
        These Tag Namespaces will provide Tags for our customers and Partners to provide consistency and enable data reporting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_import_standard_tags_management = oci.identity.ImportStandardTagsManagement("testImportStandardTagsManagement",
            compartment_id=var["compartment_id"],
            standard_tag_namespace_name=oci_identity_tag_namespace["test_tag_namespace"]["name"])
        ```

        ## Import

        ImportStandardTagsManagement can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Identity/importStandardTagsManagement:ImportStandardTagsManagement test_import_standard_tags_management "id"
        ```

        :param str resource_name: The name of the resource.
        :param ImportStandardTagsManagementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ImportStandardTagsManagementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 standard_tag_namespace_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ImportStandardTagsManagementArgs.__new__(ImportStandardTagsManagementArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            if standard_tag_namespace_name is None and not opts.urn:
                raise TypeError("Missing required property 'standard_tag_namespace_name'")
            __props__.__dict__["standard_tag_namespace_name"] = standard_tag_namespace_name
            __props__.__dict__["work_request_id"] = None
        super(ImportStandardTagsManagement, __self__).__init__(
            'oci:Identity/importStandardTagsManagement:ImportStandardTagsManagement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            standard_tag_namespace_name: Optional[pulumi.Input[str]] = None,
            work_request_id: Optional[pulumi.Input[str]] = None) -> 'ImportStandardTagsManagement':
        """
        Get an existing ImportStandardTagsManagement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        :param pulumi.Input[str] standard_tag_namespace_name: The name of standard tag namespace that will be imported in bulk 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ImportStandardTagsManagementState.__new__(_ImportStandardTagsManagementState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["standard_tag_namespace_name"] = standard_tag_namespace_name
        __props__.__dict__["work_request_id"] = work_request_id
        return ImportStandardTagsManagement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the compartment where the bulk create request is submitted and where the tag namespaces will be created.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="standardTagNamespaceName")
    def standard_tag_namespace_name(self) -> pulumi.Output[str]:
        """
        The name of standard tag namespace that will be imported in bulk 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "standard_tag_namespace_name")

    @property
    @pulumi.getter(name="workRequestId")
    def work_request_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "work_request_id")

